@@ -7,7 +7,7 @@ from pyspark.sql.types import StructField, StructType, IntegerType, TimestampTyp
 from cerebralcortex.algorithms.utils.mprov_helper import CC_MProvAgg
 
 # CREATE CC OBJECT
-CC = Kernel(cc_configs="default", )
+CC = Kernel(cc_configs="default", new_study=True)
 
 # GET STREAM DATA FOR ONE USER
 # md2k_aa_rice user_id = a57f8608-439a-4f11-9bbf-085ca01577f6
